@@ -69,7 +69,7 @@ except ImportError:
     torch_cache_home = os.path.expanduser(
         os.getenv("TORCH_HOME", os.path.join(os.getenv("XDG_CACHE_HOME", "~/.cache"), "torch"))
     )
-default_cache_path = os.path.join(torch_cache_home, "transformers")
+default_cache_path = os.path.join(torch_cache_home, "awesome-align")
 
 try:
     from pathlib import Path
