@@ -20,7 +20,6 @@ import argparse
 import random
 import itertools
 import os
-import tempfile
 import warnings
 warnings.filterwarnings("ignore")
 
@@ -164,28 +163,20 @@ def main():
     device = torch.device("cuda" if torch.cuda.is_available() and not args.no_cuda else "cpu")
     args.device = device
 
-    # Set cache dir
-    cache_dir = args.cache_dir
-    if args.cache_dir is None:
-        temp_dir = tempfile.TemporaryDirectory()
-        cache_dir = temp_dir.name
-        print("Creating a temporary directory to store pre-trained models...")
-        print("You can specify where to store the pre-trained models by setting '--cache_dir'")
-
     # Set seed
     set_seed(args)
     config_class, model_class, tokenizer_class = BertConfig, BertForMaskedLM, BertTokenizer
     if args.config_name:
-        config = config_class.from_pretrained(args.config_name, cache_dir=cache_dir)
+        config = config_class.from_pretrained(args.config_name, cache_dir=args.cache_dir)
     elif args.model_name_or_path:
-        config = config_class.from_pretrained(args.model_name_or_path, cache_dir=cache_dir)
+        config = config_class.from_pretrained(args.model_name_or_path, cache_dir=args.cache_dir)
     else:
         config = config_class()
 
     if args.tokenizer_name:
-        tokenizer = tokenizer_class.from_pretrained(args.tokenizer_name, cache_dir=cache_dir)
+        tokenizer = tokenizer_class.from_pretrained(args.tokenizer_name, cache_dir=args.cache_dir)
     elif args.model_name_or_path:
-        tokenizer = tokenizer_class.from_pretrained(args.model_name_or_path, cache_dir=cache_dir)
+        tokenizer = tokenizer_class.from_pretrained(args.model_name_or_path, cache_dir=args.cache_dir)
     else:
         raise ValueError(
             "You are instantiating a new {} tokenizer. This is not supported, but you can do it from another script, save it,"
@@ -201,15 +192,12 @@ def main():
             args.model_name_or_path,
             from_tf=bool(".ckpt" in args.model_name_or_path),
             config=config,
-            cache_dir=cache_dir,
+            cache_dir=args.cache_dir,
         )
     else:
         model = model_class(config=config)
 
     word_align(args, model, tokenizer)
 
-    if args.cache_dir is None:
-        temp_dir.cleanup()
-
 if __name__ == "__main__":
     main()
